<?php

namespace Drupal\mailjet_webform_subscription;

/**
 * Service to connect to mailjet api.
 */
interface IMailjetApiWrapperInterface {

  /**
   * Append to the mailjet mail list .
   *
   * @param string $emailAddress
   *   The email to add to list.
   * @param string|null $firstName
   *   The first name of subscriber.
   * @param string|null $lastName
   *   The last name of the subscriber.
   * @param int $listId
   *   The ID of the list to subscribe to.
   */
  public function appendToList(string $emailAddress, string|null $firstName, string|null $lastName, int $listId) : bool;

  /**
   * Send templated email.
   *
   * @param string $recipientEmail
   *   The email address to send to.
   * @param int $templateId
   *   The id of the MailJet template to use.
   * @param array $variables
   *   Variables to append to send to the template. e.g. [first_name => 'Jeff'].
   */
  public function sendTemplateEmail(string $recipientEmail, int $templateId, array $variables = []): void;

  /**
   * Get mail lists from mailjet formatted for a select input.
   *
   * @throws \Exception
   *   If there is an issue with the mailjet api.
   */
  public function getMailJetLists() : array|null;

  /**
   * Get email templates from mailjet formatted for a select input.
   *
   * @throws \Exception
   *   If there is an issue with the mailjet api.
   */
  public function getMailjetTemplates() : array;

}
